---
title: <span class="badge builder"></span> PublicDashboard
---
# <span class="badge builder"></span> PublicDashboard

## Constructor

```python
PublicDashboard()
```
## Methods

### <span class="badge object-method"></span> build

Builds the object.

```python
def build() -> publicdashboard.PublicDashboard
```

### <span class="badge object-method"></span> access_token

Unique public access token

```python
def access_token(access_token: str) -> typing.Self
```

### <span class="badge object-method"></span> annotations_enabled

Flag that indicates if annotations are enabled

```python
def annotations_enabled(annotations_enabled: bool) -> typing.Self
```

### <span class="badge object-method"></span> dashboard_uid

Dashboard unique identifier referenced by this public dashboard

```python
def dashboard_uid(dashboard_uid: str) -> typing.Self
```

### <span class="badge object-method"></span> is_enabled

Flag that indicates if the public dashboard is enabled

```python
def is_enabled(is_enabled: bool) -> typing.Self
```

### <span class="badge object-method"></span> time_selection_enabled

Flag that indicates if the time range picker is enabled

```python
def time_selection_enabled(time_selection_enabled: bool) -> typing.Self
```

### <span class="badge object-method"></span> uid

Unique public dashboard identifier

```python
def uid(uid: str) -> typing.Self
```

## See also

 * <span class="badge object-type-class"></span> [PublicDashboard](./object-PublicDashboard.md)
